@@ -1,6 +1,6 @@
 package CatalystX::Resource::Controller::Resource;
 {
-  $CatalystX::Resource::Controller::Resource::VERSION = '0.006001';
+  $CatalystX::Resource::Controller::Resource::VERSION = '0.008001';
 }
 use Moose;
 use namespace::autoclean;
@@ -53,13 +53,6 @@ has 'resultset_key' => (
 );
 
 
-has 'resources_key' => (
-    is       => 'ro',
-    isa      => NonEmptySimpleStr,
-    required => 1,
-);
-
-
 has 'resource_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
@@ -80,6 +73,12 @@ has 'parents_accessor' => (
 );
 
 
+has 'prefetch' => (
+    is        => 'ro',
+    predicate => 'has_prefetch',
+);
+
+
 has 'redirect_mode' => (
     is      => 'rw',
     isa     => NonEmptySimpleStr,
@@ -246,6 +245,11 @@ sub _msg {
             ? $c->loc( 'resources.moved_to', $self->_identifier($c) )
             : $self->_identifier($c) . " moved.";
     }
+    elsif ( $action eq 'move_to_undef' ) {
+        return $c->can('loc')
+            ? $c->loc( 'resources.move_to_undef', $self->_identifier($c) )
+            : 'Could not move ' . $self->_identifier($c) . '. No position defined.';
+    }
 }
 
 
@@ -276,6 +280,7 @@ sub base : Chained('') PathPart('') CaptureArgs(0) {
     # Store the ResultSet in stash so it's available for other methods
     # get the model from the controllers config that consumes this role
     my $resultset;
+
     if ( $self->has_parent ) {
         $resultset = $c->stash->{ $self->parent_key }
             ->related_resultset( $self->parents_accessor );
@@ -283,6 +288,10 @@ sub base : Chained('') PathPart('') CaptureArgs(0) {
     else {
         $resultset = $c->model( $self->model );
     }
+
+    $resultset = $resultset->search_rs( undef, { prefetch => $self->prefetch } )
+        if $self->has_prefetch;
+
     $c->stash( $self->resultset_key => $resultset );
 }
 
@@ -312,7 +321,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.006001
+version 0.008001
 
 =head1 ATTRIBUTES
 
@@ -336,31 +345,31 @@ if no identifier is found resource_key is used
 
 =head2 resultset_key
 
-stash key used to store the resultset of this resource. (e.g.: 'cds_rs')
-
-=head2 resources_key
-
-stash key used to store all results of this resource. (e.g.: 'tracks')
-You will need this to access a list of your resources in your template.
+stash key used to store the resultset of this resource. (e.g.: 'albums')
 
 =head2 resource_key
 
-stash key used to store specific result of this resource. (e.g.: 'track')
+stash key used to store specific result of this resource. (e.g.: 'album')
 You will need this to access your resource in your template.
 
 =head2 parent_key
 
 for a nested resource 'parent_key' is used as stash key to store the parent item
-(e.g.: 'cd')
+(e.g.: 'artist')
 this is required if parent_key is set
 
 =head2 parents_accessor
 
 the accessor on the parent resource to get a resultset
 of this resource (accessor in DBIC has_many)
-(e.g.: 'tracks')
+(e.g.: 'albums')
 this is required if parent_key is set
 
+=head2 prefetch
+
+The prefetch attribute value is passed through. See L<DBIx::Class::ResultSet> for details.
+(e.g.: 'tracks', [qw/tracks credits/])
+
 =head2 redirect_mode list|show|show_parent|show_parent_list
 
 After a created/edit/delete action a redirect takes place.
