@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use base 'Catalyst::Model::DBIC::Schema';
 
-__PACKAGE__->config( schema_class => 'TestApp::Schema', );
+__PACKAGE__->config(
+    schema_class => 'TestApp::Schema',
+);
 
 1;
